==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/9d/9dc9f3506bfdfd556140401fb453409c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-center/assets/logo_demo-company-v.svg */
class __TwigTemplate_31c9cfb28ae2478e87cd90b3bca74b88 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 324.4 52.5\" style=\"enable-background:new 0 0 324.4 52.5;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#00BF9A;}
\t.st1{fill:#007F67;}
</style>
<g>
\t<g>
\t\t<path class=\"st0\" d=\"M52.1,4.9c-1.7,0.1-3.2,0.8-4.5,2c-1.2,1.2-2.4,3.2-3.4,6L29.3,52.5h-6.1l-17.1-40C4.7,9.3,4,6.9,4,5.5L0,5.7
\t\t\tV0h21.9v4.9C18.7,4.8,17,5.9,17,8c0,0.8,0.2,1.7,0.6,2.6l6.8,16.8c0.6,1.4,1.3,3.2,2.2,5.5c0.3,0.8,1,2.5,2,5.1h0.1l3.6-10.3
\t\t\tL38,12.3c1.1-3.4,2.1-5.7,3.1-6.8V5.4l-3.9,0.2l-1.9,0.1V0h16.7V4.9z\"/>
\t</g>
\t<g>
\t\t<path class=\"st1\" d=\"M91.7,37.6c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3l0,0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0c-0.7-0.7-1.8-0.9-2.6-0.3C93.7,36.4,92.5,37.2,91.7,37.6
\t\t\tz\"/>
\t\t<path class=\"st1\" d=\"M129.7,11.9c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C134.4,15.3,132.3,13.3,129.7,11.9z M131.9,32.5c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC133.6,28.5,133,30.6,131.9,32.5z\"/>
\t\t<path class=\"st1\" d=\"M164.4,32.8l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.5l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.3c0-1.8-1.5-3.3-3.3-3.3h0c-1.2,0-2.4,0.7-2.9,1.8L164.4,32.8z\"/>
\t\t<path class=\"st1\" d=\"M214.4,12.9c-2.2-1.9-5.4-2.9-9.4-2.9h-10.3c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C217.7,17.5,216.6,14.8,214.4,12.9z M211.2,26.5
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V14.1l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C213.5,23.5,212.7,25.3,211.2,26.5z\"/>
\t\t<path class=\"st1\" d=\"M233.4,12.1l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3l0,0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C235.2,10,233.9,10.8,233.4,12.1z
\t\t\t M230.7,28.4l5.8-13.6l5.9,13.6H230.7z\"/>
\t\t<path class=\"st1\" d=\"M283.9,35.2l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7H263c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.3l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12.2c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35.2z\"/>
\t\t<path class=\"st1\" d=\"M320.6,11l-9.3,16.6L301.9,11c-0.4-0.6-1-1-1.7-1l0,0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6v7.7
\t\t\tc0,1.2,1,2.2,2.2,2.2l0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C321.7,10,321,10.4,320.6,11z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-center/assets/logo_demo-company-v.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-center/assets/logo_demo-company-v.svg", "/var/www/mautic-ktn/themes/fresh-center/assets/logo_demo-company-v.svg");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/9d/9dc9f3506bfdfd556140401fb453409c.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fresh-center/assets/logo_demo-company-v.svg */
class __TwigTemplate_31c9cfb28ae2478e87cd90b3bca74b88 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?xml version=\"1.0\" encoding=\"utf-8\"?>
<!-- Generator: Adobe Illustrator 21.1.0, SVG Export Plug-In . SVG Version: 6.00 Build 0)  -->
<svg version=\"1.1\" id=\"Layer_1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\"
\t viewBox=\"0 0 324.4 52.5\" style=\"enable-background:new 0 0 324.4 52.5;\" xml:space=\"preserve\">
<style type=\"text/css\">
\t.st0{fill:#00BF9A;}
\t.st1{fill:#007F67;}
</style>
<g>
\t<g>
\t\t<path class=\"st0\" d=\"M52.1,4.9c-1.7,0.1-3.2,0.8-4.5,2c-1.2,1.2-2.4,3.2-3.4,6L29.3,52.5h-6.1l-17.1-40C4.7,9.3,4,6.9,4,5.5L0,5.7
\t\t\tV0h21.9v4.9C18.7,4.8,17,5.9,17,8c0,0.8,0.2,1.7,0.6,2.6l6.8,16.8c0.6,1.4,1.3,3.2,2.2,5.5c0.3,0.8,1,2.5,2,5.1h0.1l3.6-10.3
\t\t\tL38,12.3c1.1-3.4,2.1-5.7,3.1-6.8V5.4l-3.9,0.2l-1.9,0.1V0h16.7V4.9z\"/>
\t</g>
\t<g>
\t\t<path class=\"st1\" d=\"M91.7,37.6c-1.6,0.7-3.3,1-5,1c-3.1,0-5.8-1-8.2-3c-0.5-0.4-1-0.9-1.4-1.5c-1.9-2.4-2.9-5-2.9-8
\t\t\tc0-2.3,0.6-4.4,1.7-6.3c1.1-1.9,2.6-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c1.7,0,3.4,0.4,5.1,1.1c0.8,0.4,1.9,1.1,2.7,1.8
\t\t\tc0.9,0.7,2.2,0.5,2.9-0.3l0,0c0.7-0.9,0.6-2.3-0.3-3c-1.2-0.9-2.5-1.6-3.9-2.2c-2.1-0.9-4.3-1.3-6.6-1.3c-3.1,0-6,0.7-8.6,2.2
\t\t\tc-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3c0,3.1,0.7,5.9,2.2,8.4c1.5,2.5,3.5,4.5,6.1,6c2.6,1.5,5.4,2.2,8.5,2.2
\t\t\tc2.2,0,4.4-0.5,6.6-1.4c1.2-0.5,2.7-1.6,3.9-2.4c1-0.7,1.1-2.1,0.3-3l0,0c-0.7-0.7-1.8-0.9-2.6-0.3C93.7,36.4,92.5,37.2,91.7,37.6
\t\t\tz\"/>
\t\t<path class=\"st1\" d=\"M129.7,11.9c-2.6-1.5-5.5-2.2-8.6-2.2c-3.2,0-6,0.7-8.6,2.2c-2.6,1.5-4.7,3.4-6.2,6c-1.5,2.5-2.3,5.3-2.3,8.3
\t\t\tc0,3,0.8,5.8,2.3,8.4c1.5,2.6,3.6,4.6,6.2,6c2.6,1.5,5.5,2.2,8.6,2.2c3.1,0,6-0.7,8.6-2.2c2.6-1.5,4.7-3.5,6.2-6
\t\t\tc1.5-2.6,2.3-5.3,2.3-8.4c0-3-0.8-5.8-2.3-8.3C134.4,15.3,132.3,13.3,129.7,11.9z M131.9,32.5c-1.1,1.9-2.6,3.4-4.6,4.6
\t\t\tc-1.9,1.1-4,1.7-6.2,1.7c-2.3,0-4.4-0.6-6.3-1.7c-1.9-1.1-3.5-2.7-4.6-4.6c-1.1-1.9-1.7-4-1.7-6.3c0-2.3,0.6-4.4,1.7-6.3
\t\t\tc1.1-1.9,2.7-3.4,4.6-4.5c1.9-1.1,4-1.7,6.3-1.7c2.3,0,4.3,0.6,6.2,1.7c1.9,1.1,3.4,2.6,4.6,4.5c1.1,1.9,1.7,4,1.7,6.3
\t\t\tC133.6,28.5,133,30.6,131.9,32.5z\"/>
\t\t<path class=\"st1\" d=\"M164.4,32.8l-11-21.1c-0.6-1.1-1.7-1.8-2.9-1.8l0,0c-1.8,0-3.3,1.5-3.3,3.3v27.2c0,1.1,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.1,0,2.1-0.9,2.1-2.1V16.5l11,21.3c0.4,0.7,1.2,1.2,2,1.2l0,0c0.8,0,1.6-0.5,2-1.2l10.9-21.3l0,23.9c0,1.2,0.9,2.1,2.1,2.1l0,0
\t\t\tc1.2,0,2.1-0.9,2.1-2.1V13.3c0-1.8-1.5-3.3-3.3-3.3h0c-1.2,0-2.4,0.7-2.9,1.8L164.4,32.8z\"/>
\t\t<path class=\"st1\" d=\"M214.4,12.9c-2.2-1.9-5.4-2.9-9.4-2.9h-10.3c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2v-7.9h8.1c4,0,7.2-1,9.4-3s3.3-4.8,3.3-8.4C217.7,17.5,216.6,14.8,214.4,12.9z M211.2,26.5
\t\t\tc-1.5,1.2-3.6,1.8-6.4,1.8h-7.9V14.1l7.9,0c2.8,0,4.9,0.6,6.4,1.8c1.5,1.2,2.2,2.9,2.2,5.3C213.5,23.5,212.7,25.3,211.2,26.5z\"/>
\t\t<path class=\"st1\" d=\"M233.4,12.1l-12.2,27.4c-0.6,1.4,0.4,3,1.9,3l0,0c0.9,0,1.6-0.5,2-1.3l3.7-8.8l15.3,0.1l3.8,8.7
\t\t\tc0.3,0.8,1.1,1.3,2,1.3l0,0c1.6,0,2.7-1.6,2-3.1l-12.1-27.3c-0.6-1.3-1.9-2.1-3.3-2.1l0,0C235.2,10,233.9,10.8,233.4,12.1z
\t\t\t M230.7,28.4l5.8-13.6l5.9,13.6H230.7z\"/>
\t\t<path class=\"st1\" d=\"M283.9,35.2l-17.4-23.5c-0.8-1.1-2-1.7-3.3-1.7H263c-1.2,0-2.2,1-2.2,2.2v28.1c0,1.2,1,2.2,2.2,2.2l0,0
\t\t\tc1.2,0,2.2-1,2.2-2.2V17.3l17.3,23.5c0.8,1.1,2.1,1.7,3.4,1.7h0.1c1.2,0,2.2-1,2.2-2.2V12.2c0-1.2-1-2.2-2.2-2.2l0,0
\t\t\tc-1.2,0-2.2,1-2.2,2.2V35.2z\"/>
\t\t<path class=\"st1\" d=\"M320.6,11l-9.3,16.6L301.9,11c-0.4-0.6-1-1-1.7-1l0,0c-1.5,0-2.5,1.6-1.8,3l10.7,19.6v7.7
\t\t\tc0,1.2,1,2.2,2.2,2.2l0,0c1.2,0,2.2-1,2.2-2.2v-7.9l10.6-19.4c0.7-1.3-0.2-3-1.8-3l0,0C321.7,10,321,10.4,320.6,11z\"/>
\t</g>
</g>
</svg>
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fresh-center/assets/logo_demo-company-v.svg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fresh-center/assets/logo_demo-company-v.svg", "/var/www/html/mauticGIT-Test/themes/fresh-center/assets/logo_demo-company-v.svg");
    }
}
